/*******************************************************************************
* File Name: TimeBaseSecnd.h  
* Version 2.30
*
* Description:
*  Contains the prototypes and constants for the functions available to the 
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_PWM_TimeBaseSecnd_H)
#define CY_PWM_TimeBaseSecnd_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 TimeBaseSecnd_initVar;


/***************************************
* Conditional Compilation Parameters
***************************************/
#define TimeBaseSecnd_Resolution 16u
#define TimeBaseSecnd_UsingFixedFunction 0u
#define TimeBaseSecnd_DeadBandMode 0u
#define TimeBaseSecnd_KillModeMinTime 0u
#define TimeBaseSecnd_KillMode 0u
#define TimeBaseSecnd_PWMMode 1u
#define TimeBaseSecnd_PWMModeIsCenterAligned 0u
#define TimeBaseSecnd_DeadBandUsed 0u
#define TimeBaseSecnd_DeadBand2_4 0u
#if !defined(TimeBaseSecnd_PWMUDB_sSTSReg_stsreg__REMOVED)
    #define TimeBaseSecnd_UseStatus 1u
#else
    #define TimeBaseSecnd_UseStatus 0u
#endif /* !defined(TimeBaseSecnd_PWMUDB_sSTSReg_stsreg__REMOVED) */
#if !defined(TimeBaseSecnd_PWMUDB_sCTRLReg_ctrlreg__REMOVED)
    #define TimeBaseSecnd_UseControl 1u
#else
    #define TimeBaseSecnd_UseControl 0u
#endif /* !defined(TimeBaseSecnd_PWMUDB_sCTRLReg_ctrlreg__REMOVED) */
#define TimeBaseSecnd_UseOneCompareMode 0u
#define TimeBaseSecnd_MinimumKillTime 1u
#define TimeBaseSecnd_EnableMode 0u

#define TimeBaseSecnd_CompareMode1SW 0u
#define TimeBaseSecnd_CompareMode2SW 0u

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component PWM_v2_30 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */

/* Use Kill Mode Enumerated Types */
#define TimeBaseSecnd__B_PWM__DISABLED 0
#define TimeBaseSecnd__B_PWM__ASYNCHRONOUS 1
#define TimeBaseSecnd__B_PWM__SINGLECYCLE 2
#define TimeBaseSecnd__B_PWM__LATCHED 3
#define TimeBaseSecnd__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define TimeBaseSecnd__B_PWM__DBMDISABLED 0
#define TimeBaseSecnd__B_PWM__DBM_2_4_CLOCKS 1
#define TimeBaseSecnd__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define TimeBaseSecnd__B_PWM__ONE_OUTPUT 0
#define TimeBaseSecnd__B_PWM__TWO_OUTPUTS 1
#define TimeBaseSecnd__B_PWM__DUAL_EDGE 2
#define TimeBaseSecnd__B_PWM__CENTER_ALIGN 3
#define TimeBaseSecnd__B_PWM__DITHER 5
#define TimeBaseSecnd__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define TimeBaseSecnd__B_PWM__LESS_THAN 1
#define TimeBaseSecnd__B_PWM__LESS_THAN_OR_EQUAL 2
#define TimeBaseSecnd__B_PWM__GREATER_THAN 3
#define TimeBaseSecnd__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define TimeBaseSecnd__B_PWM__EQUAL 0
#define TimeBaseSecnd__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct
{
    
    uint8 PWMEnableState;
       
    #if(!TimeBaseSecnd_UsingFixedFunction)
        #if (CY_PSOC5A)
            uint16 PWMUdb;               /* PWM Current Counter value  */
            uint16 PWMPeriod;            /* PWM Current Period value   */
            #if (TimeBaseSecnd_UseStatus)
                uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
            #endif /* (TimeBaseSecnd_UseStatus) */
            #if(TimeBaseSecnd_UseOneCompareMode)
                uint16 PWMCompareValue;     /* PWM Current Compare value */
            #else
                uint16 PWMCompareValue1;     /* PWM Current Compare value1 */
                uint16 PWMCompareValue2;     /* PWM Current Compare value2 */
            #endif /* (TimeBaseSecnd_UseOneCompareMode) */
            
            /* Backup for Deadband parameters */
            #if(TimeBaseSecnd_DeadBandMode == TimeBaseSecnd__B_PWM__DBM_256_CLOCKS || \
                TimeBaseSecnd_DeadBandMode == TimeBaseSecnd__B_PWM__DBM_2_4_CLOCKS)
                uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
            #endif /* deadband count is either 2-4 clocks or 256 clocks */
            
            /* Backup Kill Mode Counter*/
            #if(TimeBaseSecnd_KillModeMinTime)
                uint8 PWMKillCounterPeriod; /* Kill Mode period value */
            #endif /* (TimeBaseSecnd_KillModeMinTime) */
            
        #endif /* (CY_PSOC5A) */
        
        #if (CY_PSOC3 || CY_PSOC5LP)
            uint16 PWMUdb;               /* PWM Current Counter value  */
            #if(!TimeBaseSecnd_PWMModeIsCenterAligned)
                uint16 PWMPeriod;
            #endif /* (!TimeBaseSecnd_PWMModeIsCenterAligned) */
            #if (TimeBaseSecnd_UseStatus)
                uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
            #endif /* (TimeBaseSecnd_UseStatus) */
            
            /* Backup for Deadband parameters */
            #if(TimeBaseSecnd_DeadBandMode == TimeBaseSecnd__B_PWM__DBM_256_CLOCKS || \
                TimeBaseSecnd_DeadBandMode == TimeBaseSecnd__B_PWM__DBM_2_4_CLOCKS)
                uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
            #endif /* deadband count is either 2-4 clocks or 256 clocks */
            
            /* Backup Kill Mode Counter*/
            #if(TimeBaseSecnd_KillModeMinTime)
                uint8 PWMKillCounterPeriod; /* Kill Mode period value */
            #endif /* (TimeBaseSecnd_KillModeMinTime) */
        #endif /* (CY_PSOC3 || CY_PSOC5LP) */
        
        
        /* Backup control register */
        #if(TimeBaseSecnd_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif /* (TimeBaseSecnd_UseControl) */
        
    #endif /* (!TimeBaseSecnd_UsingFixedFunction) */
   
}TimeBaseSecnd_backupStruct;


/***************************************
*        Function Prototypes
 **************************************/
 
void    TimeBaseSecnd_Start(void) ;
void    TimeBaseSecnd_Stop(void) ;

#if (TimeBaseSecnd_UseStatus || TimeBaseSecnd_UsingFixedFunction)
    void  TimeBaseSecnd_SetInterruptMode(uint8 interruptMode) ;
    uint8 TimeBaseSecnd_ReadStatusRegister(void) ;
#endif /* (TimeBaseSecnd_UseStatus || TimeBaseSecnd_UsingFixedFunction) */

#define TimeBaseSecnd_GetInterruptSource() TimeBaseSecnd_ReadStatusRegister()

#if (TimeBaseSecnd_UseControl)
    uint8 TimeBaseSecnd_ReadControlRegister(void) ; 
    void  TimeBaseSecnd_WriteControlRegister(uint8 control) ;
#endif /* (TimeBaseSecnd_UseControl) */

#if (TimeBaseSecnd_UseOneCompareMode)
   #if (TimeBaseSecnd_CompareMode1SW)
       void    TimeBaseSecnd_SetCompareMode(uint8 comparemode) ;
   #endif /* (TimeBaseSecnd_CompareMode1SW) */
#else
    #if (TimeBaseSecnd_CompareMode1SW)
        void    TimeBaseSecnd_SetCompareMode1(uint8 comparemode) ;
    #endif /* (TimeBaseSecnd_CompareMode1SW) */
    #if (TimeBaseSecnd_CompareMode2SW)
        void    TimeBaseSecnd_SetCompareMode2(uint8 comparemode) ;
    #endif /* (TimeBaseSecnd_CompareMode2SW) */
#endif /* (TimeBaseSecnd_UseOneCompareMode) */

#if (!TimeBaseSecnd_UsingFixedFunction)
    uint16   TimeBaseSecnd_ReadCounter(void) ;
    uint16 TimeBaseSecnd_ReadCapture(void) ;
    
	#if (TimeBaseSecnd_UseStatus)
	        void TimeBaseSecnd_ClearFIFO(void) ;
	#endif /* (TimeBaseSecnd_UseStatus) */

    void    TimeBaseSecnd_WriteCounter(uint16 counter) ;
#endif /* (!TimeBaseSecnd_UsingFixedFunction) */

void    TimeBaseSecnd_WritePeriod(uint16 period) ;
uint16 TimeBaseSecnd_ReadPeriod(void) ;

#if (TimeBaseSecnd_UseOneCompareMode)
    void    TimeBaseSecnd_WriteCompare(uint16 compare) ;
    uint16 TimeBaseSecnd_ReadCompare(void) ; 
#else
    void    TimeBaseSecnd_WriteCompare1(uint16 compare) ;
    uint16 TimeBaseSecnd_ReadCompare1(void) ; 
    void    TimeBaseSecnd_WriteCompare2(uint16 compare) ;
    uint16 TimeBaseSecnd_ReadCompare2(void) ; 
#endif /* (TimeBaseSecnd_UseOneCompareMode) */


#if (TimeBaseSecnd_DeadBandUsed)
    void    TimeBaseSecnd_WriteDeadTime(uint8 deadtime) ;
    uint8   TimeBaseSecnd_ReadDeadTime(void) ;
#endif /* (TimeBaseSecnd_DeadBandUsed) */

#if ( TimeBaseSecnd_KillModeMinTime)
    void TimeBaseSecnd_WriteKillTime(uint8 killtime) ;
    uint8 TimeBaseSecnd_ReadKillTime(void) ; 
#endif /* ( TimeBaseSecnd_KillModeMinTime) */

void TimeBaseSecnd_Init(void) ;
void TimeBaseSecnd_Enable(void) ;
void TimeBaseSecnd_Sleep(void) ;
void TimeBaseSecnd_Wakeup(void) ;
void TimeBaseSecnd_SaveConfig(void) ;
void TimeBaseSecnd_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define TimeBaseSecnd_INIT_PERIOD_VALUE        15000u
#define TimeBaseSecnd_INIT_COMPARE_VALUE1      5000u
#define TimeBaseSecnd_INIT_COMPARE_VALUE2      200u
#define TimeBaseSecnd_INIT_INTERRUPTS_MODE     (uint8)(((uint8)(0u << TimeBaseSecnd_STATUS_TC_INT_EN_MASK_SHIFT)) | \
                                                  (uint8)((uint8)(0u << TimeBaseSecnd_STATUS_CMP2_INT_EN_MASK_SHIFT)) | \
                                                  (uint8)((uint8)(1u << TimeBaseSecnd_STATUS_CMP1_INT_EN_MASK_SHIFT )) | \
                                                  (uint8)((uint8)(0u << TimeBaseSecnd_STATUS_KILL_INT_EN_MASK_SHIFT )))
#define TimeBaseSecnd_DEFAULT_COMPARE2_MODE    (uint8)((uint8)1u << TimeBaseSecnd_CTRL_CMPMODE2_SHIFT)
#define TimeBaseSecnd_DEFAULT_COMPARE1_MODE    (uint8)((uint8)1u << TimeBaseSecnd_CTRL_CMPMODE1_SHIFT)
#define TimeBaseSecnd_INIT_DEAD_TIME           1u


/********************************
*         Registers
******************************** */

#if (TimeBaseSecnd_UsingFixedFunction)
   #define TimeBaseSecnd_PERIOD_LSB          (*(reg16 *) TimeBaseSecnd_PWMHW__PER0)
   #define TimeBaseSecnd_PERIOD_LSB_PTR      ( (reg16 *) TimeBaseSecnd_PWMHW__PER0)
   #define TimeBaseSecnd_COMPARE1_LSB        (*(reg16 *) TimeBaseSecnd_PWMHW__CNT_CMP0)
   #define TimeBaseSecnd_COMPARE1_LSB_PTR    ( (reg16 *) TimeBaseSecnd_PWMHW__CNT_CMP0)
   #define TimeBaseSecnd_COMPARE2_LSB        0x00u
   #define TimeBaseSecnd_COMPARE2_LSB_PTR    0x00u
   #define TimeBaseSecnd_COUNTER_LSB         (*(reg16 *) TimeBaseSecnd_PWMHW__CNT_CMP0)
   #define TimeBaseSecnd_COUNTER_LSB_PTR     ( (reg16 *) TimeBaseSecnd_PWMHW__CNT_CMP0)
   #define TimeBaseSecnd_CAPTURE_LSB         (*(reg16 *) TimeBaseSecnd_PWMHW__CAP0)
   #define TimeBaseSecnd_CAPTURE_LSB_PTR     ( (reg16 *) TimeBaseSecnd_PWMHW__CAP0)
   #define TimeBaseSecnd_RT1                 (*(reg8 *)  TimeBaseSecnd_PWMHW__RT1)
   #define TimeBaseSecnd_RT1_PTR             ( (reg8 *)  TimeBaseSecnd_PWMHW__RT1)
      
#else
   #if (TimeBaseSecnd_Resolution == 8u) /* 8bit - PWM */
	   
	   #if(TimeBaseSecnd_PWMModeIsCenterAligned)
	       #define TimeBaseSecnd_PERIOD_LSB      (*(reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__D1_REG)
	       #define TimeBaseSecnd_PERIOD_LSB_PTR   ((reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__D1_REG)
	   #else
	       #define TimeBaseSecnd_PERIOD_LSB      (*(reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__F0_REG)
	       #define TimeBaseSecnd_PERIOD_LSB_PTR   ((reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__F0_REG)
	   #endif /* (TimeBaseSecnd_PWMModeIsCenterAligned) */
	   
	   #define TimeBaseSecnd_COMPARE1_LSB    (*(reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__D0_REG)
	   #define TimeBaseSecnd_COMPARE1_LSB_PTR ((reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__D0_REG)
	   #define TimeBaseSecnd_COMPARE2_LSB    (*(reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__D1_REG)
	   #define TimeBaseSecnd_COMPARE2_LSB_PTR ((reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__D1_REG)
	   #define TimeBaseSecnd_COUNTERCAP_LSB   (*(reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__A1_REG)
	   #define TimeBaseSecnd_COUNTERCAP_LSB_PTR ((reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__A1_REG)
	   #define TimeBaseSecnd_COUNTER_LSB     (*(reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__A0_REG)
	   #define TimeBaseSecnd_COUNTER_LSB_PTR  ((reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__A0_REG)
	   #define TimeBaseSecnd_CAPTURE_LSB     (*(reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__F1_REG)
	   #define TimeBaseSecnd_CAPTURE_LSB_PTR  ((reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__F1_REG)
   
   #else
   		#if(CY_PSOC3) /* 8-bit address space */	
			#if(TimeBaseSecnd_PWMModeIsCenterAligned)
		       #define TimeBaseSecnd_PERIOD_LSB      (*(reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__D1_REG)
		       #define TimeBaseSecnd_PERIOD_LSB_PTR   ((reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__D1_REG)
		    #else
		       #define TimeBaseSecnd_PERIOD_LSB      (*(reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__F0_REG)
		       #define TimeBaseSecnd_PERIOD_LSB_PTR   ((reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__F0_REG)
		    #endif /* (TimeBaseSecnd_PWMModeIsCenterAligned) */
		   
		    #define TimeBaseSecnd_COMPARE1_LSB    (*(reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__D0_REG)
		    #define TimeBaseSecnd_COMPARE1_LSB_PTR ((reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__D0_REG)
		    #define TimeBaseSecnd_COMPARE2_LSB    (*(reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__D1_REG)
		    #define TimeBaseSecnd_COMPARE2_LSB_PTR ((reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__D1_REG)
		    #define TimeBaseSecnd_COUNTERCAP_LSB   (*(reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__A1_REG)
		    #define TimeBaseSecnd_COUNTERCAP_LSB_PTR ((reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__A1_REG)
		    #define TimeBaseSecnd_COUNTER_LSB     (*(reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__A0_REG)
		    #define TimeBaseSecnd_COUNTER_LSB_PTR  ((reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__A0_REG)
		    #define TimeBaseSecnd_CAPTURE_LSB     (*(reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__F1_REG)
		    #define TimeBaseSecnd_CAPTURE_LSB_PTR  ((reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__F1_REG)
		#else
			#if(TimeBaseSecnd_PWMModeIsCenterAligned)
		       #define TimeBaseSecnd_PERIOD_LSB      (*(reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__16BIT_D1_REG)
		       #define TimeBaseSecnd_PERIOD_LSB_PTR   ((reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__16BIT_D1_REG)
		    #else
		       #define TimeBaseSecnd_PERIOD_LSB      (*(reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__16BIT_F0_REG)
		       #define TimeBaseSecnd_PERIOD_LSB_PTR   ((reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__16BIT_F0_REG)
		    #endif /* (TimeBaseSecnd_PWMModeIsCenterAligned) */
		   
		    #define TimeBaseSecnd_COMPARE1_LSB    (*(reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__16BIT_D0_REG)
		    #define TimeBaseSecnd_COMPARE1_LSB_PTR ((reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__16BIT_D0_REG)
		    #define TimeBaseSecnd_COMPARE2_LSB    (*(reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__16BIT_D1_REG)
		    #define TimeBaseSecnd_COMPARE2_LSB_PTR ((reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__16BIT_D1_REG)
		    #define TimeBaseSecnd_COUNTERCAP_LSB   (*(reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__16BIT_A1_REG)
		    #define TimeBaseSecnd_COUNTERCAP_LSB_PTR ((reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__16BIT_A1_REG)
		    #define TimeBaseSecnd_COUNTER_LSB     (*(reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__16BIT_A0_REG)
		    #define TimeBaseSecnd_COUNTER_LSB_PTR  ((reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__16BIT_A0_REG)
		    #define TimeBaseSecnd_CAPTURE_LSB     (*(reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__16BIT_F1_REG)
		    #define TimeBaseSecnd_CAPTURE_LSB_PTR  ((reg16 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__16BIT_F1_REG)
		#endif
		
	   #define TimeBaseSecnd_AUX_CONTROLDP1    (*(reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u1__DP_AUX_CTL_REG)
       #define TimeBaseSecnd_AUX_CONTROLDP1_PTR  ((reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u1__DP_AUX_CTL_REG)

   #endif /* (TimeBaseSecnd_Resolution == 8) */
   
   #define TimeBaseSecnd_AUX_CONTROLDP0      (*(reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__DP_AUX_CTL_REG)
   #define TimeBaseSecnd_AUX_CONTROLDP0_PTR  ((reg8 *) TimeBaseSecnd_PWMUDB_sP16_pwmdp_u0__DP_AUX_CTL_REG)

#endif /* (TimeBaseSecnd_UsingFixedFunction) */
   
#if(TimeBaseSecnd_KillModeMinTime )
    #define TimeBaseSecnd_KILLMODEMINTIME      (*(reg8 *) TimeBaseSecnd_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define TimeBaseSecnd_KILLMODEMINTIME_PTR   ((reg8 *) TimeBaseSecnd_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif /* (TimeBaseSecnd_KillModeMinTime ) */

#if(TimeBaseSecnd_DeadBandMode == TimeBaseSecnd__B_PWM__DBM_256_CLOCKS)
    #define TimeBaseSecnd_DEADBAND_COUNT      (*(reg8 *) TimeBaseSecnd_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define TimeBaseSecnd_DEADBAND_COUNT_PTR  ((reg8 *) TimeBaseSecnd_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define TimeBaseSecnd_DEADBAND_LSB_PTR    ((reg8 *) TimeBaseSecnd_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define TimeBaseSecnd_DEADBAND_LSB        (*(reg8 *) TimeBaseSecnd_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(TimeBaseSecnd_DeadBandMode == TimeBaseSecnd__B_PWM__DBM_2_4_CLOCKS)
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (TimeBaseSecnd_UsingFixedFunction)
        #define TimeBaseSecnd_DEADBAND_COUNT        (*(reg8 *) TimeBaseSecnd_PWMHW__CFG0) 
        #define TimeBaseSecnd_DEADBAND_COUNT_PTR     ((reg8 *) TimeBaseSecnd_PWMHW__CFG0)
        #define TimeBaseSecnd_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << TimeBaseSecnd_DEADBAND_COUNT_SHIFT)
        /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */
        #define TimeBaseSecnd_DEADBAND_COUNT_SHIFT   0x06u  
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define TimeBaseSecnd_DEADBAND_COUNT        (*(reg8 *) TimeBaseSecnd_PWMUDB_sDB3_AsyncCtl_dbctrlreg__CONTROL_REG)
        #define TimeBaseSecnd_DEADBAND_COUNT_PTR     ((reg8 *) TimeBaseSecnd_PWMUDB_sDB3_AsyncCtl_dbctrlreg__CONTROL_REG)
        #define TimeBaseSecnd_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << TimeBaseSecnd_DEADBAND_COUNT_SHIFT) 
        /* As defined by the verilog implementation of the Control Register */
        #define TimeBaseSecnd_DEADBAND_COUNT_SHIFT   0x00u 
    #endif /* (TimeBaseSecnd_UsingFixedFunction) */
#endif /* (TimeBaseSecnd_DeadBandMode == TimeBaseSecnd__B_PWM__DBM_256_CLOCKS) */



#if (TimeBaseSecnd_UsingFixedFunction)
    #define TimeBaseSecnd_STATUS                (*(reg8 *) TimeBaseSecnd_PWMHW__SR0)
    #define TimeBaseSecnd_STATUS_PTR            ((reg8 *) TimeBaseSecnd_PWMHW__SR0)
    #define TimeBaseSecnd_STATUS_MASK           (*(reg8 *) TimeBaseSecnd_PWMHW__SR0)
    #define TimeBaseSecnd_STATUS_MASK_PTR       ((reg8 *) TimeBaseSecnd_PWMHW__SR0)
    #define TimeBaseSecnd_CONTROL               (*(reg8 *) TimeBaseSecnd_PWMHW__CFG0)
    #define TimeBaseSecnd_CONTROL_PTR           ((reg8 *) TimeBaseSecnd_PWMHW__CFG0)    
    #define TimeBaseSecnd_CONTROL2              (*(reg8 *) TimeBaseSecnd_PWMHW__CFG1)    
    #if(CY_PSOC3 || CY_PSOC5LP)
        #define TimeBaseSecnd_CONTROL3              (*(reg8 *) TimeBaseSecnd_PWMHW__CFG2)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    #define TimeBaseSecnd_GLOBAL_ENABLE         (*(reg8 *) TimeBaseSecnd_PWMHW__PM_ACT_CFG)
    #define TimeBaseSecnd_GLOBAL_ENABLE_PTR       ( (reg8 *) TimeBaseSecnd_PWMHW__PM_ACT_CFG)
    #define TimeBaseSecnd_GLOBAL_STBY_ENABLE      (*(reg8 *) TimeBaseSecnd_PWMHW__PM_STBY_CFG)
    #define TimeBaseSecnd_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) TimeBaseSecnd_PWMHW__PM_STBY_CFG)
  
  
    /***********************************
    *          Constants
    ***********************************/

    /* Fixed Function Block Chosen */
    #define TimeBaseSecnd_BLOCK_EN_MASK          TimeBaseSecnd_PWMHW__PM_ACT_MSK
    #define TimeBaseSecnd_BLOCK_STBY_EN_MASK     TimeBaseSecnd_PWMHW__PM_STBY_MSK 
    /* Control Register definitions */
    #define TimeBaseSecnd_CTRL_ENABLE_SHIFT      0x00u
    
    #if(CY_PSOC5A)
        #define TimeBaseSecnd_CTRL_CMPMODE1_SHIFT    0x01u   /* As defined by Register map as MODE_CFG bits in CFG1*/
    #endif /* (CY_PSOC5A) */
    #if(CY_PSOC3 || CY_PSOC5LP)
        #define TimeBaseSecnd_CTRL_CMPMODE1_SHIFT    0x04u  /* As defined by Register map as MODE_CFG bits in CFG2*/
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    
    #define TimeBaseSecnd_CTRL_DEAD_TIME_SHIFT   0x06u   /* As defined by Register map */
    /* Fixed Function Block Only CFG register bit definitions */
    #define TimeBaseSecnd_CFG0_MODE              0x02u   /*  Set to compare mode */
    /* #define TimeBaseSecnd_CFG0_ENABLE            0x01u */  /* Enable the block to run */
    #define TimeBaseSecnd_CFG0_DB                0x20u   /* As defined by Register map as DB bit in CFG0 */

    /* Control Register Bit Masks */
    #define TimeBaseSecnd_CTRL_ENABLE            (uint8)((uint8)0x01u << TimeBaseSecnd_CTRL_ENABLE_SHIFT)
    #define TimeBaseSecnd_CTRL_RESET             (uint8)((uint8)0x01u << TimeBaseSecnd_CTRL_RESET_SHIFT)
    #define TimeBaseSecnd_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << TimeBaseSecnd_CTRL_CMPMODE2_SHIFT)
    #if(CY_PSOC5A)
        #define TimeBaseSecnd_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << TimeBaseSecnd_CTRL_CMPMODE1_SHIFT)
    #endif /* (CY_PSOC5A) */
    #if(CY_PSOC3 || CY_PSOC5LP)
        #define TimeBaseSecnd_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << TimeBaseSecnd_CTRL_CMPMODE1_SHIFT)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    
    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define TimeBaseSecnd_CTRL2_IRQ_SEL_SHIFT    0x00u       
    #define TimeBaseSecnd_CTRL2_IRQ_SEL          (uint8)((uint8)0x01u << TimeBaseSecnd_CTRL2_IRQ_SEL_SHIFT)  
    
    /* Status Register Bit Locations */
    #define TimeBaseSecnd_STATUS_TC_SHIFT            0x07u   /* As defined by Register map as TC in SR0 */
    #define TimeBaseSecnd_STATUS_CMP1_SHIFT          0x06u   /* As defined by the Register map as CAP_CMP in SR0 */
    
    /* Status Register Interrupt Enable Bit Locations */
    #define TimeBaseSecnd_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)    
    #define TimeBaseSecnd_STATUS_TC_INT_EN_MASK_SHIFT            (TimeBaseSecnd_STATUS_TC_SHIFT - 4u)
    #define TimeBaseSecnd_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)  
    #define TimeBaseSecnd_STATUS_CMP1_INT_EN_MASK_SHIFT          (TimeBaseSecnd_STATUS_CMP1_SHIFT - 4u)
    
    /* Status Register Bit Masks */
    #define TimeBaseSecnd_STATUS_TC              (uint8)((uint8)0x01u << TimeBaseSecnd_STATUS_TC_SHIFT)
    #define TimeBaseSecnd_STATUS_CMP1            (uint8)((uint8)0x01u << TimeBaseSecnd_STATUS_CMP1_SHIFT)
    
    /* Status Register Interrupt Bit Masks*/
    #define TimeBaseSecnd_STATUS_TC_INT_EN_MASK              (uint8)((uint8)TimeBaseSecnd_STATUS_TC >> 4u)
    #define TimeBaseSecnd_STATUS_CMP1_INT_EN_MASK            (uint8)((uint8)TimeBaseSecnd_STATUS_CMP1 >> 4u)
    
    /*RT1 Synch Constants: Applicable for PSoC3 and PSoC5LP*/
    #define TimeBaseSecnd_RT1_SHIFT             0x04u
    #define TimeBaseSecnd_RT1_MASK              (uint8)((uint8)0x03u << TimeBaseSecnd_RT1_SHIFT)/* Sync TC and CMP bit masks */
    #define TimeBaseSecnd_SYNC                  (uint8)((uint8)0x03u << TimeBaseSecnd_RT1_SHIFT)
    #define TimeBaseSecnd_SYNCDSI_SHIFT         0x00u
    #define TimeBaseSecnd_SYNCDSI_MASK          (uint8)((uint8)0x0Fu << TimeBaseSecnd_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    #define TimeBaseSecnd_SYNCDSI_EN            (uint8)((uint8)0x0Fu << TimeBaseSecnd_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    

#else
    #define TimeBaseSecnd_STATUS                (*(reg8 *) TimeBaseSecnd_PWMUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define TimeBaseSecnd_STATUS_PTR            ((reg8 *) TimeBaseSecnd_PWMUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define TimeBaseSecnd_STATUS_MASK           (*(reg8 *) TimeBaseSecnd_PWMUDB_sSTSReg_nrstSts_stsreg__MASK_REG)
    #define TimeBaseSecnd_STATUS_MASK_PTR       ((reg8 *) TimeBaseSecnd_PWMUDB_sSTSReg_nrstSts_stsreg__MASK_REG)
    #define TimeBaseSecnd_STATUS_AUX_CTRL       (*(reg8 *) TimeBaseSecnd_PWMUDB_sSTSReg_nrstSts_stsreg__STATUS_AUX_CTL_REG)
    #define TimeBaseSecnd_CONTROL               (*(reg8 *) TimeBaseSecnd_PWMUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG)
    #define TimeBaseSecnd_CONTROL_PTR           ((reg8 *) TimeBaseSecnd_PWMUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG)
    
    
    /***********************************
    *          Constants
    ***********************************/

    /* Control Register definitions */
    #define TimeBaseSecnd_CTRL_ENABLE_SHIFT      0x07u
    #define TimeBaseSecnd_CTRL_RESET_SHIFT       0x06u
    #define TimeBaseSecnd_CTRL_CMPMODE2_SHIFT    0x03u
    #define TimeBaseSecnd_CTRL_CMPMODE1_SHIFT    0x00u
    #define TimeBaseSecnd_CTRL_DEAD_TIME_SHIFT   0x00u   /* No Shift Needed for UDB block */
    /* Control Register Bit Masks */
    #define TimeBaseSecnd_CTRL_ENABLE            (uint8)((uint8)0x01u << TimeBaseSecnd_CTRL_ENABLE_SHIFT)
    #define TimeBaseSecnd_CTRL_RESET             (uint8)((uint8)0x01u << TimeBaseSecnd_CTRL_RESET_SHIFT)
    #define TimeBaseSecnd_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << TimeBaseSecnd_CTRL_CMPMODE2_SHIFT)
    #define TimeBaseSecnd_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << TimeBaseSecnd_CTRL_CMPMODE1_SHIFT) 
    
    /* Status Register Bit Locations */
    #define TimeBaseSecnd_STATUS_KILL_SHIFT          0x05u
    #define TimeBaseSecnd_STATUS_FIFONEMPTY_SHIFT    0x04u
    #define TimeBaseSecnd_STATUS_FIFOFULL_SHIFT      0x03u  
    #define TimeBaseSecnd_STATUS_TC_SHIFT            0x02u
    #define TimeBaseSecnd_STATUS_CMP2_SHIFT          0x01u
    #define TimeBaseSecnd_STATUS_CMP1_SHIFT          0x00u
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define TimeBaseSecnd_STATUS_KILL_INT_EN_MASK_SHIFT          TimeBaseSecnd_STATUS_KILL_SHIFT          
    #define TimeBaseSecnd_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    TimeBaseSecnd_STATUS_FIFONEMPTY_SHIFT    
    #define TimeBaseSecnd_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      TimeBaseSecnd_STATUS_FIFOFULL_SHIFT        
    #define TimeBaseSecnd_STATUS_TC_INT_EN_MASK_SHIFT            TimeBaseSecnd_STATUS_TC_SHIFT            
    #define TimeBaseSecnd_STATUS_CMP2_INT_EN_MASK_SHIFT          TimeBaseSecnd_STATUS_CMP2_SHIFT          
    #define TimeBaseSecnd_STATUS_CMP1_INT_EN_MASK_SHIFT          TimeBaseSecnd_STATUS_CMP1_SHIFT   
    /* Status Register Bit Masks */
    #define TimeBaseSecnd_STATUS_KILL            (uint8)((uint8)0x00u << TimeBaseSecnd_STATUS_KILL_SHIFT )
    #define TimeBaseSecnd_STATUS_FIFOFULL        (uint8)((uint8)0x01u << TimeBaseSecnd_STATUS_FIFOFULL_SHIFT)
    #define TimeBaseSecnd_STATUS_FIFONEMPTY      (uint8)((uint8)0x01u << TimeBaseSecnd_STATUS_FIFONEMPTY_SHIFT)
    #define TimeBaseSecnd_STATUS_TC              (uint8)((uint8)0x01u << TimeBaseSecnd_STATUS_TC_SHIFT)
    #define TimeBaseSecnd_STATUS_CMP2            (uint8)((uint8)0x01u << TimeBaseSecnd_STATUS_CMP2_SHIFT) 
    #define TimeBaseSecnd_STATUS_CMP1            (uint8)((uint8)0x01u << TimeBaseSecnd_STATUS_CMP1_SHIFT)
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define TimeBaseSecnd_STATUS_KILL_INT_EN_MASK            TimeBaseSecnd_STATUS_KILL
    #define TimeBaseSecnd_STATUS_FIFOFULL_INT_EN_MASK        TimeBaseSecnd_STATUS_FIFOFULL
    #define TimeBaseSecnd_STATUS_FIFONEMPTY_INT_EN_MASK      TimeBaseSecnd_STATUS_FIFONEMPTY
    #define TimeBaseSecnd_STATUS_TC_INT_EN_MASK              TimeBaseSecnd_STATUS_TC
    #define TimeBaseSecnd_STATUS_CMP2_INT_EN_MASK            TimeBaseSecnd_STATUS_CMP2
    #define TimeBaseSecnd_STATUS_CMP1_INT_EN_MASK            TimeBaseSecnd_STATUS_CMP1
                                                          
    /* Datapath Auxillary Control Register definitions */
    #define TimeBaseSecnd_AUX_CTRL_FIFO0_CLR     0x01u
    #define TimeBaseSecnd_AUX_CTRL_FIFO1_CLR     0x02u
    #define TimeBaseSecnd_AUX_CTRL_FIFO0_LVL     0x04u
    #define TimeBaseSecnd_AUX_CTRL_FIFO1_LVL     0x08u
    #define TimeBaseSecnd_STATUS_ACTL_INT_EN_MASK  0x10u /* As defined for the ACTL Register */
#endif /* TimeBaseSecnd_UsingFixedFunction */

#endif  /* CY_PWM_TimeBaseSecnd_H */


/* [] END OF FILE */
