/*******************************************************************************
* File Name: TimeBaseSecnd_PM.c
* Version 2.30
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "cytypes.h"
#include "TimeBaseSecnd.h"

static TimeBaseSecnd_backupStruct TimeBaseSecnd_backup;


/*******************************************************************************
* Function Name: TimeBaseSecnd_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*  
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  TimeBaseSecnd_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
*******************************************************************************/
void TimeBaseSecnd_SaveConfig(void) 
{
    
    #if(!TimeBaseSecnd_UsingFixedFunction)
        #if (CY_PSOC5A)
            TimeBaseSecnd_backup.PWMUdb = TimeBaseSecnd_ReadCounter();
            TimeBaseSecnd_backup.PWMPeriod = TimeBaseSecnd_ReadPeriod();
            #if (TimeBaseSecnd_UseStatus)
                TimeBaseSecnd_backup.InterruptMaskValue = TimeBaseSecnd_STATUS_MASK;
            #endif /* (TimeBaseSecnd_UseStatus) */
            
            #if(TimeBaseSecnd_UseOneCompareMode)
                TimeBaseSecnd_backup.PWMCompareValue = TimeBaseSecnd_ReadCompare();
            #else
                TimeBaseSecnd_backup.PWMCompareValue1 = TimeBaseSecnd_ReadCompare1();
                TimeBaseSecnd_backup.PWMCompareValue2 = TimeBaseSecnd_ReadCompare2();
            #endif /* (TimeBaseSecnd_UseOneCompareMode) */
            
           #if(TimeBaseSecnd_DeadBandUsed)
                TimeBaseSecnd_backup.PWMdeadBandValue = TimeBaseSecnd_ReadDeadTime();
            #endif /* (TimeBaseSecnd_DeadBandUsed) */
          
            #if ( TimeBaseSecnd_KillModeMinTime)
                TimeBaseSecnd_backup.PWMKillCounterPeriod = TimeBaseSecnd_ReadKillTime();
            #endif /* ( TimeBaseSecnd_KillModeMinTime) */
        #endif /* (CY_PSOC5A) */
        
        #if (CY_PSOC3 || CY_PSOC5LP)
            #if(!TimeBaseSecnd_PWMModeIsCenterAligned)
                TimeBaseSecnd_backup.PWMPeriod = TimeBaseSecnd_ReadPeriod();
            #endif /* (!TimeBaseSecnd_PWMModeIsCenterAligned) */
            TimeBaseSecnd_backup.PWMUdb = TimeBaseSecnd_ReadCounter();
            #if (TimeBaseSecnd_UseStatus)
                TimeBaseSecnd_backup.InterruptMaskValue = TimeBaseSecnd_STATUS_MASK;
            #endif /* (TimeBaseSecnd_UseStatus) */
            
            #if(TimeBaseSecnd_DeadBandMode == TimeBaseSecnd__B_PWM__DBM_256_CLOCKS || \
                TimeBaseSecnd_DeadBandMode == TimeBaseSecnd__B_PWM__DBM_2_4_CLOCKS)
                TimeBaseSecnd_backup.PWMdeadBandValue = TimeBaseSecnd_ReadDeadTime();
            #endif /*  deadband count is either 2-4 clocks or 256 clocks */
            
            #if(TimeBaseSecnd_KillModeMinTime)
                 TimeBaseSecnd_backup.PWMKillCounterPeriod = TimeBaseSecnd_ReadKillTime();
            #endif /* (TimeBaseSecnd_KillModeMinTime) */
        #endif /* (CY_PSOC3 || CY_PSOC5LP) */
        
        #if(TimeBaseSecnd_UseControl)
            TimeBaseSecnd_backup.PWMControlRegister = TimeBaseSecnd_ReadControlRegister();
        #endif /* (TimeBaseSecnd_UseControl) */
    #endif  /* (!TimeBaseSecnd_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: TimeBaseSecnd_RestoreConfig
********************************************************************************
* 
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  TimeBaseSecnd_backup:  Variables of this global structure are used to  
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void TimeBaseSecnd_RestoreConfig(void) 
{
        #if(!TimeBaseSecnd_UsingFixedFunction)
            #if (CY_PSOC5A)
                /* Interrupt State Backup for Critical Region*/
                uint8 TimeBaseSecnd_interruptState;
                /* Enter Critical Region*/
                TimeBaseSecnd_interruptState = CyEnterCriticalSection();
                #if (TimeBaseSecnd_UseStatus)
                    /* Use the interrupt output of the status register for IRQ output */
                    TimeBaseSecnd_STATUS_AUX_CTRL |= TimeBaseSecnd_STATUS_ACTL_INT_EN_MASK;
                    
                    TimeBaseSecnd_STATUS_MASK = TimeBaseSecnd_backup.InterruptMaskValue;
                #endif /* (TimeBaseSecnd_UseStatus) */
                
                #if (TimeBaseSecnd_Resolution == 8)
                    /* Set FIFO 0 to 1 byte register for period*/
                    TimeBaseSecnd_AUX_CONTROLDP0 |= (TimeBaseSecnd_AUX_CTRL_FIFO0_CLR);
                #else /* (TimeBaseSecnd_Resolution == 16)*/
                    /* Set FIFO 0 to 1 byte register for period */
                    TimeBaseSecnd_AUX_CONTROLDP0 |= (TimeBaseSecnd_AUX_CTRL_FIFO0_CLR);
                    TimeBaseSecnd_AUX_CONTROLDP1 |= (TimeBaseSecnd_AUX_CTRL_FIFO0_CLR);
                #endif /* (TimeBaseSecnd_Resolution == 8) */
                /* Exit Critical Region*/
                CyExitCriticalSection(TimeBaseSecnd_interruptState);
                
                TimeBaseSecnd_WriteCounter(TimeBaseSecnd_backup.PWMUdb);
                TimeBaseSecnd_WritePeriod(TimeBaseSecnd_backup.PWMPeriod);
                
                #if(TimeBaseSecnd_UseOneCompareMode)
                    TimeBaseSecnd_WriteCompare(TimeBaseSecnd_backup.PWMCompareValue);
                #else
                    TimeBaseSecnd_WriteCompare1(TimeBaseSecnd_backup.PWMCompareValue1);
                    TimeBaseSecnd_WriteCompare2(TimeBaseSecnd_backup.PWMCompareValue2);
                #endif /* (TimeBaseSecnd_UseOneCompareMode) */
                
               #if(TimeBaseSecnd_DeadBandMode == TimeBaseSecnd__B_PWM__DBM_256_CLOCKS || \
                   TimeBaseSecnd_DeadBandMode == TimeBaseSecnd__B_PWM__DBM_2_4_CLOCKS)
                    TimeBaseSecnd_WriteDeadTime(TimeBaseSecnd_backup.PWMdeadBandValue);
                #endif /* deadband count is either 2-4 clocks or 256 clocks */
            
                #if ( TimeBaseSecnd_KillModeMinTime)
                    TimeBaseSecnd_WriteKillTime(TimeBaseSecnd_backup.PWMKillCounterPeriod);
                #endif /* ( TimeBaseSecnd_KillModeMinTime) */
            #endif /* (CY_PSOC5A) */
            
            #if (CY_PSOC3 || CY_PSOC5LP)
                #if(!TimeBaseSecnd_PWMModeIsCenterAligned)
                    TimeBaseSecnd_WritePeriod(TimeBaseSecnd_backup.PWMPeriod);
                #endif /* (!TimeBaseSecnd_PWMModeIsCenterAligned) */
                TimeBaseSecnd_WriteCounter(TimeBaseSecnd_backup.PWMUdb);
                #if (TimeBaseSecnd_UseStatus)
                    TimeBaseSecnd_STATUS_MASK = TimeBaseSecnd_backup.InterruptMaskValue;
                #endif /* (TimeBaseSecnd_UseStatus) */
                
                #if(TimeBaseSecnd_DeadBandMode == TimeBaseSecnd__B_PWM__DBM_256_CLOCKS || \
                    TimeBaseSecnd_DeadBandMode == TimeBaseSecnd__B_PWM__DBM_2_4_CLOCKS)
                    TimeBaseSecnd_WriteDeadTime(TimeBaseSecnd_backup.PWMdeadBandValue);
                #endif /* deadband count is either 2-4 clocks or 256 clocks */
                
                #if(TimeBaseSecnd_KillModeMinTime)
                    TimeBaseSecnd_WriteKillTime(TimeBaseSecnd_backup.PWMKillCounterPeriod);
                #endif /* (TimeBaseSecnd_KillModeMinTime) */
            #endif /* (CY_PSOC3 || CY_PSOC5LP) */
            
            #if(TimeBaseSecnd_UseControl)
                TimeBaseSecnd_WriteControlRegister(TimeBaseSecnd_backup.PWMControlRegister); 
            #endif /* (TimeBaseSecnd_UseControl) */
        #endif  /* (!TimeBaseSecnd_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: TimeBaseSecnd_Sleep
********************************************************************************
* 
* Summary:
*  Disables block's operation and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  TimeBaseSecnd_backup.PWMEnableState:  Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void TimeBaseSecnd_Sleep(void) 
{
    #if(TimeBaseSecnd_UseControl)
        if(TimeBaseSecnd_CTRL_ENABLE == (TimeBaseSecnd_CONTROL & TimeBaseSecnd_CTRL_ENABLE))
        {
            /*Component is enabled */
            TimeBaseSecnd_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            TimeBaseSecnd_backup.PWMEnableState = 0u;
        }
    #endif /* (TimeBaseSecnd_UseControl) */

    /* Stop component */
    TimeBaseSecnd_Stop();
    
    /* Save registers configuration */
    TimeBaseSecnd_SaveConfig();
}


/*******************************************************************************
* Function Name: TimeBaseSecnd_Wakeup
********************************************************************************
* 
* Summary:
*  Restores and enables the user configuration. Should be called just after 
*  awaking from sleep.
*  
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  TimeBaseSecnd_backup.pwmEnable:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void TimeBaseSecnd_Wakeup(void) 
{
     /* Restore registers values */
    TimeBaseSecnd_RestoreConfig();
    
    if(TimeBaseSecnd_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        TimeBaseSecnd_Enable();
    } /* Do nothing if component's block was disabled before */
    
}


/* [] END OF FILE */
