/*******************************************************************************
* File Name: WidthCtr.h
* Version 2.40
*
*  Description:
*     Contains the function prototypes and constants available to the timer
*     user module.
*
*   Note:
*     None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_Timer_v2_30_WidthCtr_H)
#define CY_Timer_v2_30_WidthCtr_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 WidthCtr_initVar;

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component Timer_v2_40 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */


/**************************************
*           Parameter Defaults
**************************************/

#define WidthCtr_Resolution                 16u
#define WidthCtr_UsingFixedFunction         0u
#define WidthCtr_UsingHWCaptureCounter      0u
#define WidthCtr_SoftwareCaptureMode        0u
#define WidthCtr_SoftwareTriggerMode        0u
#define WidthCtr_UsingHWEnable              0u
#define WidthCtr_EnableTriggerMode          0u
#define WidthCtr_InterruptOnCaptureCount    1u
#define WidthCtr_RunModeUsed                0u
#define WidthCtr_ControlRegRemoved          0u


/***************************************
*       Type defines
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for Timer Component
 *************************************************************************/
typedef struct
{
    uint8 TimerEnableState;
    #if(!WidthCtr_UsingFixedFunction)
        #if (CY_PSOC5A)
            uint16 TimerUdb;                 /* Timer internal counter value */
            uint16 TimerPeriod;              /* Timer Period value       */
            uint8 InterruptMaskValue;       /* Timer Compare Value */
            #if (WidthCtr_UsingHWCaptureCounter)
                uint8 TimerCaptureCounter;  /* Timer Capture Counter Value */
            #endif /* variable declaration for backing up Capture Counter value*/
        #endif /* variables for non retention registers in PSoC5A */

        #if (CY_PSOC3 || CY_PSOC5LP)
            uint16 TimerUdb;
            uint8 InterruptMaskValue;
            #if (WidthCtr_UsingHWCaptureCounter)
                uint8 TimerCaptureCounter;
            #endif /* variable declarations for backing up non retention registers in PSoC3 or PSoC5LP */
        #endif /* (CY_PSOC3 || CY_PSOC5LP) */

        #if (!WidthCtr_ControlRegRemoved)
        uint8 TimerControlRegister;
        #endif /* variable declaration for backing up enable state of the Timer */
    #endif /* define backup variables only for UDB implementation. Fixed function registers are all retention */
}WidthCtr_backupStruct;


/***************************************
*       Function Prototypes
***************************************/

void    WidthCtr_Start(void) ;
void    WidthCtr_Stop(void) ;

void    WidthCtr_SetInterruptMode(uint8 interruptMode) ;
uint8   WidthCtr_ReadStatusRegister(void) ;
/* Deprecated function. Do not use this in future. Retained for backward compatibility */
#define WidthCtr_GetInterruptSource() WidthCtr_ReadStatusRegister()

#if(!WidthCtr_ControlRegRemoved)
    uint8   WidthCtr_ReadControlRegister(void) ;
    void    WidthCtr_WriteControlRegister(uint8 control) \
        ;
#endif /* (!WidthCtr_ControlRegRemoved) */

uint16  WidthCtr_ReadPeriod(void) ;
void    WidthCtr_WritePeriod(uint16 period) \
    ;
uint16  WidthCtr_ReadCounter(void) ;
void    WidthCtr_WriteCounter(uint16 counter) \
    ;
uint16  WidthCtr_ReadCapture(void) ;
void    WidthCtr_SoftwareCapture(void) ;


#if(!WidthCtr_UsingFixedFunction) /* UDB Prototypes */
    #if (WidthCtr_SoftwareCaptureMode)
        void    WidthCtr_SetCaptureMode(uint8 captureMode) ;
    #endif /* (!WidthCtr_UsingFixedFunction) */

    #if (WidthCtr_SoftwareTriggerMode)
        void    WidthCtr_SetTriggerMode(uint8 triggerMode) ;
    #endif /* (WidthCtr_SoftwareTriggerMode) */
    #if (WidthCtr_EnableTriggerMode)
        void    WidthCtr_EnableTrigger(void) ;
        void    WidthCtr_DisableTrigger(void) ;
    #endif /* (WidthCtr_EnableTriggerMode) */

    #if(WidthCtr_InterruptOnCaptureCount)
        #if(!WidthCtr_ControlRegRemoved)
            void    WidthCtr_SetInterruptCount(uint8 interruptCount) \
                ;
        #endif /* (!WidthCtr_ControlRegRemoved) */
    #endif /* (WidthCtr_InterruptOnCaptureCount) */

    #if (WidthCtr_UsingHWCaptureCounter)
        void    WidthCtr_SetCaptureCount(uint8 captureCount) \
            ;
        uint8   WidthCtr_ReadCaptureCount(void) ;
    #endif /* (WidthCtr_UsingHWCaptureCounter) */

    void WidthCtr_ClearFIFO(void) ;
#endif /* UDB Prototypes */

/* Sleep Retention APIs */
void WidthCtr_Init(void)          ;
void WidthCtr_Enable(void)        ;
void WidthCtr_SaveConfig(void)    ;
void WidthCtr_RestoreConfig(void) ;
void WidthCtr_Sleep(void)         ;
void WidthCtr_Wakeup(void)        ;


/***************************************
*   Enumerated Types and Parameters
***************************************/

/* Enumerated Type B_Timer__CaptureModes, Used in Capture Mode */
#define WidthCtr__B_TIMER__CM_NONE 0
#define WidthCtr__B_TIMER__CM_RISINGEDGE 1
#define WidthCtr__B_TIMER__CM_FALLINGEDGE 2
#define WidthCtr__B_TIMER__CM_EITHEREDGE 3
#define WidthCtr__B_TIMER__CM_SOFTWARE 4



/* Enumerated Type B_Timer__TriggerModes, Used in Trigger Mode */
#define WidthCtr__B_TIMER__TM_NONE 0x00u
#define WidthCtr__B_TIMER__TM_RISINGEDGE 0x04u
#define WidthCtr__B_TIMER__TM_FALLINGEDGE 0x08u
#define WidthCtr__B_TIMER__TM_EITHEREDGE 0x0Cu
#define WidthCtr__B_TIMER__TM_SOFTWARE 0x10u


/***************************************
*    Initialial Parameter Constants
***************************************/

#define WidthCtr_INIT_PERIOD             65535u
#define WidthCtr_INIT_CAPTURE_MODE       ((uint8)((uint8)1u << WidthCtr_CTRL_CAP_MODE_SHIFT))
#define WidthCtr_INIT_TRIGGER_MODE       ((uint8)((uint8)0u << WidthCtr_CTRL_TRIG_MODE_SHIFT))
#if (WidthCtr_UsingFixedFunction)
    #define WidthCtr_INIT_INTERRUPT_MODE (((uint8)((uint8)0u << WidthCtr_STATUS_TC_INT_MASK_SHIFT)) | \
                                                  ((uint8)((uint8)1 << WidthCtr_STATUS_CAPTURE_INT_MASK_SHIFT)))
#else
    #define WidthCtr_INIT_INTERRUPT_MODE (((uint8)((uint8)0u << WidthCtr_STATUS_TC_INT_MASK_SHIFT)) | \
                                                 ((uint8)((uint8)1 << WidthCtr_STATUS_CAPTURE_INT_MASK_SHIFT)) | \
                                                 ((uint8)((uint8)0 << WidthCtr_STATUS_FIFOFULL_INT_MASK_SHIFT)))
#endif /* (WidthCtr_UsingFixedFunction) */
#define WidthCtr_INIT_CAPTURE_COUNT      (2u)
#define WidthCtr_INIT_INT_CAPTURE_COUNT  ((uint8)((uint8)(1u - 1u) << WidthCtr_CTRL_INTCNT_SHIFT))


/***************************************
*           Registers
***************************************/

#if (WidthCtr_UsingFixedFunction) /* Implementation Specific Registers and Register Constants */


    /***************************************
    *    Fixed Function Registers
    ***************************************/

    #define WidthCtr_STATUS         (*(reg8 *) WidthCtr_TimerHW__SR0 )
    /* In Fixed Function Block Status and Mask are the same register */
    #define WidthCtr_STATUS_MASK    (*(reg8 *) WidthCtr_TimerHW__SR0 )
    #define WidthCtr_CONTROL        (*(reg8 *) WidthCtr_TimerHW__CFG0)
    #define WidthCtr_CONTROL2       (*(reg8 *) WidthCtr_TimerHW__CFG1)
    #define WidthCtr_CONTROL2_PTR   ( (reg8 *) WidthCtr_TimerHW__CFG1)
    #define WidthCtr_RT1            (*(reg8 *) WidthCtr_TimerHW__RT1)
    #define WidthCtr_RT1_PTR        ( (reg8 *) WidthCtr_TimerHW__RT1)

    #if (CY_PSOC3 || CY_PSOC5LP)
        #define WidthCtr_CONTROL3       (*(reg8 *) WidthCtr_TimerHW__CFG2)
        #define WidthCtr_CONTROL3_PTR   ( (reg8 *) WidthCtr_TimerHW__CFG2)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    #define WidthCtr_GLOBAL_ENABLE  (*(reg8 *) WidthCtr_TimerHW__PM_ACT_CFG)
    #define WidthCtr_GLOBAL_STBY_ENABLE  (*(reg8 *) WidthCtr_TimerHW__PM_STBY_CFG)

    #define WidthCtr_CAPTURE_LSB         (* (reg16 *) WidthCtr_TimerHW__CAP0 )
    #define WidthCtr_CAPTURE_LSB_PTR       ((reg16 *) WidthCtr_TimerHW__CAP0 )
    #define WidthCtr_PERIOD_LSB          (* (reg16 *) WidthCtr_TimerHW__PER0 )
    #define WidthCtr_PERIOD_LSB_PTR        ((reg16 *) WidthCtr_TimerHW__PER0 )
    #define WidthCtr_COUNTER_LSB         (* (reg16 *) WidthCtr_TimerHW__CNT_CMP0 )
    #define WidthCtr_COUNTER_LSB_PTR       ((reg16 *) WidthCtr_TimerHW__CNT_CMP0 )


    /***************************************
    *    Register Constants
    ***************************************/

    /* Fixed Function Block Chosen */
    #define WidthCtr_BLOCK_EN_MASK                     WidthCtr_TimerHW__PM_ACT_MSK
    #define WidthCtr_BLOCK_STBY_EN_MASK                WidthCtr_TimerHW__PM_STBY_MSK

    /* Control Register Bit Locations */
    /* Interrupt Count - Not valid for Fixed Function Block */
    #define WidthCtr_CTRL_INTCNT_SHIFT                  0x00u
    /* Trigger Polarity - Not valid for Fixed Function Block */
    #define WidthCtr_CTRL_TRIG_MODE_SHIFT               0x00u
    /* Trigger Enable - Not valid for Fixed Function Block */
    #define WidthCtr_CTRL_TRIG_EN_SHIFT                 0x00u
    /* Capture Polarity - Not valid for Fixed Function Block */
    #define WidthCtr_CTRL_CAP_MODE_SHIFT                0x00u
    /* Timer Enable - As defined in Register Map, part of TMRX_CFG0 register */
    #define WidthCtr_CTRL_ENABLE_SHIFT                  0x00u

    /* Control Register Bit Masks */
    #define WidthCtr_CTRL_ENABLE                        ((uint8)((uint8)0x01u << WidthCtr_CTRL_ENABLE_SHIFT))

    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define WidthCtr_CTRL2_IRQ_SEL_SHIFT                 0x00u
    #define WidthCtr_CTRL2_IRQ_SEL                      ((uint8)((uint8)0x01u << WidthCtr_CTRL2_IRQ_SEL_SHIFT))

    #if (CY_PSOC5A)
        /* Use CFG1 Mode bits to set run mode */
        /* As defined by Verilog Implementation */
        #define WidthCtr_CTRL_MODE_SHIFT                     0x01u
        #define WidthCtr_CTRL_MODE_MASK                     ((uint8)((uint8)0x07u << WidthCtr_CTRL_MODE_SHIFT))
    #endif /* (CY_PSOC5A) */
    #if (CY_PSOC3 || CY_PSOC5LP)
        /* Control3 Register Bit Locations */
        #define WidthCtr_CTRL_RCOD_SHIFT        0x02u
        #define WidthCtr_CTRL_ENBL_SHIFT        0x00u
        #define WidthCtr_CTRL_MODE_SHIFT        0x00u

        /* Control3 Register Bit Masks */
        #define WidthCtr_CTRL_RCOD_MASK  ((uint8)((uint8)0x03u << WidthCtr_CTRL_RCOD_SHIFT)) /* ROD and COD bit masks */
        #define WidthCtr_CTRL_ENBL_MASK  ((uint8)((uint8)0x80u << WidthCtr_CTRL_ENBL_SHIFT)) /* HW_EN bit mask */
        #define WidthCtr_CTRL_MODE_MASK  ((uint8)((uint8)0x03u << WidthCtr_CTRL_MODE_SHIFT)) /* Run mode bit mask */

        #define WidthCtr_CTRL_RCOD       ((uint8)((uint8)0x03u << WidthCtr_CTRL_RCOD_SHIFT))
        #define WidthCtr_CTRL_ENBL       ((uint8)((uint8)0x80u << WidthCtr_CTRL_ENBL_SHIFT))
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */

    /*RT1 Synch Constants: Applicable for PSoC3 and PSoC5LP */
    #define WidthCtr_RT1_SHIFT                       0x04u
    /* Sync TC and CMP bit masks */
    #define WidthCtr_RT1_MASK                        ((uint8)((uint8)0x03u << WidthCtr_RT1_SHIFT))
    #define WidthCtr_SYNC                            ((uint8)((uint8)0x03u << WidthCtr_RT1_SHIFT))
    #define WidthCtr_SYNCDSI_SHIFT                   0x00u
    /* Sync all DSI inputs with Mask  */
    #define WidthCtr_SYNCDSI_MASK                    ((uint8)((uint8)0x0Fu << WidthCtr_SYNCDSI_SHIFT))
    /* Sync all DSI inputs */
    #define WidthCtr_SYNCDSI_EN                      ((uint8)((uint8)0x0Fu << WidthCtr_SYNCDSI_SHIFT))

    #define WidthCtr_CTRL_MODE_PULSEWIDTH            ((uint8)((uint8)0x01u << WidthCtr_CTRL_MODE_SHIFT))
    #define WidthCtr_CTRL_MODE_PERIOD                ((uint8)((uint8)0x02u << WidthCtr_CTRL_MODE_SHIFT))
    #define WidthCtr_CTRL_MODE_CONTINUOUS            ((uint8)((uint8)0x00u << WidthCtr_CTRL_MODE_SHIFT))

    /* Status Register Bit Locations */
    /* As defined in Register Map, part of TMRX_SR0 register */
    #define WidthCtr_STATUS_TC_SHIFT                 0x07u
    /* As defined in Register Map, part of TMRX_SR0 register, Shared with Compare Status */
    #define WidthCtr_STATUS_CAPTURE_SHIFT            0x06u
    /* As defined in Register Map, part of TMRX_SR0 register */
    #define WidthCtr_STATUS_TC_INT_MASK_SHIFT        (WidthCtr_STATUS_TC_SHIFT - 0x04u)
    /* As defined in Register Map, part of TMRX_SR0 register, Shared with Compare Status */
    #define WidthCtr_STATUS_CAPTURE_INT_MASK_SHIFT   (WidthCtr_STATUS_CAPTURE_SHIFT - 0x04u)

    /* Status Register Bit Masks */
    #define WidthCtr_STATUS_TC                       ((uint8)((uint8)0x01u << WidthCtr_STATUS_TC_SHIFT))
    #define WidthCtr_STATUS_CAPTURE                  ((uint8)((uint8)0x01u << WidthCtr_STATUS_CAPTURE_SHIFT))
    /* Interrupt Enable Bit-Mask for interrupt on TC */
    #define WidthCtr_STATUS_TC_INT_MASK              ((uint8)((uint8)0x01u << WidthCtr_STATUS_TC_INT_MASK_SHIFT))
    /* Interrupt Enable Bit-Mask for interrupt on Capture */
    #define WidthCtr_STATUS_CAPTURE_INT_MASK         ((uint8)((uint8)0x01u << WidthCtr_STATUS_CAPTURE_INT_MASK_SHIFT))

#else   /* UDB Registers and Register Constants */


    /***************************************
    *           UDB Registers
    ***************************************/

    #define WidthCtr_STATUS              (* (reg8 *) WidthCtr_TimerUDB_nrstSts_stsreg__STATUS_REG )
    #define WidthCtr_STATUS_MASK         (* (reg8 *) WidthCtr_TimerUDB_nrstSts_stsreg__MASK_REG)
    #define WidthCtr_STATUS_AUX_CTRL     (* (reg8 *) WidthCtr_TimerUDB_nrstSts_stsreg__STATUS_AUX_CTL_REG)
    #define WidthCtr_CONTROL             (* (reg8 *) WidthCtr_TimerUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG )
    
    #if(WidthCtr_Resolution <= 8u) /* 8-bit Timer */
        #define WidthCtr_CAPTURE_LSB         (* (reg8 *) WidthCtr_TimerUDB_sT16_timerdp_u0__F0_REG )
        #define WidthCtr_CAPTURE_LSB_PTR       ((reg8 *) WidthCtr_TimerUDB_sT16_timerdp_u0__F0_REG )
        #define WidthCtr_PERIOD_LSB          (* (reg8 *) WidthCtr_TimerUDB_sT16_timerdp_u0__D0_REG )
        #define WidthCtr_PERIOD_LSB_PTR        ((reg8 *) WidthCtr_TimerUDB_sT16_timerdp_u0__D0_REG )
        #define WidthCtr_COUNTER_LSB         (* (reg8 *) WidthCtr_TimerUDB_sT16_timerdp_u0__A0_REG )
        #define WidthCtr_COUNTER_LSB_PTR       ((reg8 *) WidthCtr_TimerUDB_sT16_timerdp_u0__A0_REG )
    #elif(WidthCtr_Resolution <= 16u) /* 8-bit Timer */
        #if(CY_PSOC3) /* 8-bit addres space */
            #define WidthCtr_CAPTURE_LSB         (* (reg16 *) WidthCtr_TimerUDB_sT16_timerdp_u0__F0_REG )
            #define WidthCtr_CAPTURE_LSB_PTR       ((reg16 *) WidthCtr_TimerUDB_sT16_timerdp_u0__F0_REG )
            #define WidthCtr_PERIOD_LSB          (* (reg16 *) WidthCtr_TimerUDB_sT16_timerdp_u0__D0_REG )
            #define WidthCtr_PERIOD_LSB_PTR        ((reg16 *) WidthCtr_TimerUDB_sT16_timerdp_u0__D0_REG )
            #define WidthCtr_COUNTER_LSB         (* (reg16 *) WidthCtr_TimerUDB_sT16_timerdp_u0__A0_REG )
            #define WidthCtr_COUNTER_LSB_PTR       ((reg16 *) WidthCtr_TimerUDB_sT16_timerdp_u0__A0_REG )
        #else /* 16-bit address space */
            #define WidthCtr_CAPTURE_LSB         (* (reg16 *) WidthCtr_TimerUDB_sT16_timerdp_u0__16BIT_F0_REG )
            #define WidthCtr_CAPTURE_LSB_PTR       ((reg16 *) WidthCtr_TimerUDB_sT16_timerdp_u0__16BIT_F0_REG )
            #define WidthCtr_PERIOD_LSB          (* (reg16 *) WidthCtr_TimerUDB_sT16_timerdp_u0__16BIT_D0_REG )
            #define WidthCtr_PERIOD_LSB_PTR        ((reg16 *) WidthCtr_TimerUDB_sT16_timerdp_u0__16BIT_D0_REG )
            #define WidthCtr_COUNTER_LSB         (* (reg16 *) WidthCtr_TimerUDB_sT16_timerdp_u0__16BIT_A0_REG )
            #define WidthCtr_COUNTER_LSB_PTR       ((reg16 *) WidthCtr_TimerUDB_sT16_timerdp_u0__16BIT_A0_REG )
        #endif /* CY_PSOC3 */
    #elif(WidthCtr_Resolution <= 24u)/* 24-bit Timer */
        #define WidthCtr_CAPTURE_LSB         (* (reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__F0_REG )
        #define WidthCtr_CAPTURE_LSB_PTR       ((reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__F0_REG )
        #define WidthCtr_PERIOD_LSB          (* (reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__D0_REG )
        #define WidthCtr_PERIOD_LSB_PTR        ((reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__D0_REG )
        #define WidthCtr_COUNTER_LSB         (* (reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__A0_REG )
        #define WidthCtr_COUNTER_LSB_PTR       ((reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__A0_REG )
    #else /* 32-bit Timer */
        #if(CY_PSOC3 || CY_PSOC5) /* 8-bit address space */
            #define WidthCtr_CAPTURE_LSB         (* (reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__F0_REG )
            #define WidthCtr_CAPTURE_LSB_PTR       ((reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__F0_REG )
            #define WidthCtr_PERIOD_LSB          (* (reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__D0_REG )
            #define WidthCtr_PERIOD_LSB_PTR        ((reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__D0_REG )
            #define WidthCtr_COUNTER_LSB         (* (reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__A0_REG )
            #define WidthCtr_COUNTER_LSB_PTR       ((reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__A0_REG )
        #else /* 32-bit address space */
            #define WidthCtr_CAPTURE_LSB         (* (reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__32BIT_F0_REG )
            #define WidthCtr_CAPTURE_LSB_PTR       ((reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__32BIT_F0_REG )
            #define WidthCtr_PERIOD_LSB          (* (reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__32BIT_D0_REG )
            #define WidthCtr_PERIOD_LSB_PTR        ((reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__32BIT_D0_REG )
            #define WidthCtr_COUNTER_LSB         (* (reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__32BIT_A0_REG )
            #define WidthCtr_COUNTER_LSB_PTR       ((reg32 *) WidthCtr_TimerUDB_sT16_timerdp_u0__32BIT_A0_REG )
        #endif /* CY_PSOC3 || CY_PSOC5 */ 
    #endif

    #if (WidthCtr_UsingHWCaptureCounter)
        #define WidthCtr_CAP_COUNT              (*(reg8 *) WidthCtr_TimerUDB_sCapCount_counter__PERIOD_REG )
        #define WidthCtr_CAP_COUNT_PTR          ( (reg8 *) WidthCtr_TimerUDB_sCapCount_counter__PERIOD_REG )
        #define WidthCtr_CAPTURE_COUNT_CTRL     (*(reg8 *) WidthCtr_TimerUDB_sCapCount_counter__CONTROL_AUX_CTL_REG )
        #define WidthCtr_CAPTURE_COUNT_CTRL_PTR ( (reg8 *) WidthCtr_TimerUDB_sCapCount_counter__CONTROL_AUX_CTL_REG )
    #endif /* (WidthCtr_UsingHWCaptureCounter) */


    /***************************************
    *       Register Constants
    ***************************************/

    /* Control Register Bit Locations */
    #define WidthCtr_CTRL_INTCNT_SHIFT              0x00u       /* As defined by Verilog Implementation */
    #define WidthCtr_CTRL_TRIG_MODE_SHIFT           0x02u       /* As defined by Verilog Implementation */
    #define WidthCtr_CTRL_TRIG_EN_SHIFT             0x04u       /* As defined by Verilog Implementation */
    #define WidthCtr_CTRL_CAP_MODE_SHIFT            0x05u       /* As defined by Verilog Implementation */
    #define WidthCtr_CTRL_ENABLE_SHIFT              0x07u       /* As defined by Verilog Implementation */

    /* Control Register Bit Masks */
    #define WidthCtr_CTRL_INTCNT_MASK               ((uint8)((uint8)0x03u << WidthCtr_CTRL_INTCNT_SHIFT))
    #define WidthCtr_CTRL_TRIG_MODE_MASK            ((uint8)((uint8)0x03u << WidthCtr_CTRL_TRIG_MODE_SHIFT))
    #define WidthCtr_CTRL_TRIG_EN                   ((uint8)((uint8)0x01u << WidthCtr_CTRL_TRIG_EN_SHIFT))
    #define WidthCtr_CTRL_CAP_MODE_MASK             ((uint8)((uint8)0x03u << WidthCtr_CTRL_CAP_MODE_SHIFT))
    #define WidthCtr_CTRL_ENABLE                    ((uint8)((uint8)0x01u << WidthCtr_CTRL_ENABLE_SHIFT))

    /* Bit Counter (7-bit) Control Register Bit Definitions */
    /* As defined by the Register map for the AUX Control Register */
    #define WidthCtr_CNTR_ENABLE                    0x20u

    /* Status Register Bit Locations */
    #define WidthCtr_STATUS_TC_SHIFT                0x00u  /* As defined by Verilog Implementation */
    #define WidthCtr_STATUS_CAPTURE_SHIFT           0x01u  /* As defined by Verilog Implementation */
    #define WidthCtr_STATUS_TC_INT_MASK_SHIFT       WidthCtr_STATUS_TC_SHIFT
    #define WidthCtr_STATUS_CAPTURE_INT_MASK_SHIFT  WidthCtr_STATUS_CAPTURE_SHIFT
    #define WidthCtr_STATUS_FIFOFULL_SHIFT          0x02u  /* As defined by Verilog Implementation */
    #define WidthCtr_STATUS_FIFONEMP_SHIFT          0x03u  /* As defined by Verilog Implementation */
    #define WidthCtr_STATUS_FIFOFULL_INT_MASK_SHIFT WidthCtr_STATUS_FIFOFULL_SHIFT

    /* Status Register Bit Masks */
    /* Sticky TC Event Bit-Mask */
    #define WidthCtr_STATUS_TC                      ((uint8)((uint8)0x01u << WidthCtr_STATUS_TC_SHIFT))
    /* Sticky Capture Event Bit-Mask */
    #define WidthCtr_STATUS_CAPTURE                 ((uint8)((uint8)0x01u << WidthCtr_STATUS_CAPTURE_SHIFT))
    /* Interrupt Enable Bit-Mask */
    #define WidthCtr_STATUS_TC_INT_MASK             ((uint8)((uint8)0x01u << WidthCtr_STATUS_TC_SHIFT))
    /* Interrupt Enable Bit-Mask */
    #define WidthCtr_STATUS_CAPTURE_INT_MASK        ((uint8)((uint8)0x01u << WidthCtr_STATUS_CAPTURE_SHIFT))
    /* NOT-Sticky FIFO Full Bit-Mask */
    #define WidthCtr_STATUS_FIFOFULL                ((uint8)((uint8)0x01u << WidthCtr_STATUS_FIFOFULL_SHIFT))
    /* NOT-Sticky FIFO Not Empty Bit-Mask */
    #define WidthCtr_STATUS_FIFONEMP                ((uint8)((uint8)0x01u << WidthCtr_STATUS_FIFONEMP_SHIFT))
    /* Interrupt Enable Bit-Mask */
    #define WidthCtr_STATUS_FIFOFULL_INT_MASK       ((uint8)((uint8)0x01u << WidthCtr_STATUS_FIFOFULL_SHIFT))

    #define WidthCtr_STATUS_ACTL_INT_EN             0x10u   /* As defined for the ACTL Register */

    /* Datapath Auxillary Control Register definitions */
    #define WidthCtr_AUX_CTRL_FIFO0_CLR             0x01u   /* As defined by Register map */
    #define WidthCtr_AUX_CTRL_FIFO1_CLR             0x02u   /* As defined by Register map */
    #define WidthCtr_AUX_CTRL_FIFO0_LVL             0x04u   /* As defined by Register map */
    #define WidthCtr_AUX_CTRL_FIFO1_LVL             0x08u   /* As defined by Register map */
    #define WidthCtr_STATUS_ACTL_INT_EN_MASK        0x10u   /* As defined for the ACTL Register */

#endif /* Implementation Specific Registers and Register Constants */

#endif  /* CY_Timer_v2_30_WidthCtr_H */


/* [] END OF FILE */
