/*******************************************************************************
* File Name: WidthISR.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <WidthISR.H>

#if !defined(WidthISR__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START WidthISR_intc` */

/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE      16
#endif /* CYINT_IRQ_BASE */
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif /* CYINT_VECT_TABLE */

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: WidthISR_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void WidthISR_Start(void)
{
    /* For all we know the interrupt is active. */
    WidthISR_Disable();

    /* Set the ISR to point to the WidthISR Interrupt. */
    WidthISR_SetVector(&WidthISR_Interrupt);

    /* Set the priority. */
    WidthISR_SetPriority((uint8)WidthISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    WidthISR_Enable();
}


/*******************************************************************************
* Function Name: WidthISR_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void WidthISR_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    WidthISR_Disable();

    /* Set the ISR to point to the WidthISR Interrupt. */
    WidthISR_SetVector(address);

    /* Set the priority. */
    WidthISR_SetPriority((uint8)WidthISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    WidthISR_Enable();
}


/*******************************************************************************
* Function Name: WidthISR_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void WidthISR_Stop(void)
{
    /* Disable this interrupt. */
    WidthISR_Disable();

    /* Set the ISR to point to the passive one. */
    WidthISR_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: WidthISR_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for WidthISR.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(WidthISR_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START WidthISR_Interrupt` */

    /* `#END` */
}


/*******************************************************************************
* Function Name: WidthISR_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling WidthISR_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use WidthISR_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void WidthISR_SetVector(cyisraddress address)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + (uint32)WidthISR__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: WidthISR_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress WidthISR_GetVector(void)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + (uint32)WidthISR__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: WidthISR_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling WidthISR_Start
*   or WidthISR_StartEx will override any effect this method 
*   would have had. This method should only be called after 
*   WidthISR_Start or WidthISR_StartEx has been called. To set 
*   the initial priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void WidthISR_SetPriority(uint8 priority)
{
    *WidthISR_INTC_PRIOR = priority << 5;
}


/*******************************************************************************
* Function Name: WidthISR_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*******************************************************************************/
uint8 WidthISR_GetPriority(void)
{
    uint8 priority;


    priority = *WidthISR_INTC_PRIOR >> 5;

    return priority;
}


/*******************************************************************************
* Function Name: WidthISR_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void WidthISR_Enable(void)
{
    /* Enable the general interrupt. */
    *WidthISR_INTC_SET_EN = WidthISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: WidthISR_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 WidthISR_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*WidthISR_INTC_SET_EN & (uint32)WidthISR__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: WidthISR_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void WidthISR_Disable(void)
{
    /* Disable the general interrupt. */
    *WidthISR_INTC_CLR_EN = WidthISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: WidthISR_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void WidthISR_SetPending(void)
{
    *WidthISR_INTC_SET_PD = WidthISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: WidthISR_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void WidthISR_ClearPending(void)
{
    *WidthISR_INTC_CLR_PD = WidthISR__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
